"use client";
import React, { useEffect, useState } from "react";
import { useParams, useRouter } from "next/navigation";
import Sidebar from "../../../components/dashboard/Sidebar";
import Properties from "../Properties";
import CarouselMulti from "../Carousel";
import CarouselCard from "../../../components/dashboard/CarouselCard";
import axios from "@/services/APIservices";

const Page = () => {
  const params = useParams();
  const router = useRouter();
  const userId = params.id;

  const [userData, setUserData] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // Fetch user data function
  const fetchUserData = async () => {
    try {
      const response = await axios.get(`/api/dashboard/${userId}`);
      if (response.data.success) {
        setUserData(response.data.data);
        setError(null); // Clear any previous errors
      } else {
        throw new Error("Failed to fetch user data");
      }
    } catch (err) {
      console.error("Error fetching user data:", err);
      setError("Failed to load user details");
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    // Initial data fetch
    fetchUserData();

    // Set up polling for real-time updates every 10 seconds
    const intervalId = setInterval(fetchUserData, 5000);

    // Cleanup interval on component unmount
    return () => clearInterval(intervalId);
  }, [userId]);

  if (loading) {
    return (
      <div className="flex justify-center items-center h-screen">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-brand"></div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="flex justify-center items-center h-screen text-red-500">
        {error}
      </div>
    );
  }

  return (
    <div className="bg-[#ededed] min-h-screen flex flex-col px-4 md:px-8 lg:px-16 py-4">
      <div className="flex flex-col lg:flex-row gap-4 lg:gap-16">
        <div className="w-full lg:w-1/4">
          <Sidebar path="/dashboard" 
          userId={userData ? userData.id : null}
          userImage={userData ? userData.profile_photo : null}  
          />
        </div>
        <div className="w-full lg:w-3/4">
          <Properties
            userName={userData ? userData.name : "Guest"}
            totalPosts={userData?.total_posts}
            activePosts={userData?.active_posts}
            inactivePosts={userData?.inactive_posts}
            rejectedStatusPosts={userData?.rejected_status_posts}
          />
          <CarouselMulti size={4}>
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
            <CarouselCard />
          </CarouselMulti>
        </div>
      </div>
    </div>
  );
};

export default Page;
